import { useRef, useState, useEffect } from 'react';
import { connect, history } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProTable, TableDropdown,ProFormSelect
} from '@ant-design/pro-components';
import { Button, Image, ConfigProvider, Popconfirm, message , Tag} from 'antd';
import { GetTalentsinfoList,PostTalentsinfoDel} from '@/apis/api';
import { Imageprefix } from '@/constants';
const selectfieldNames = { label: 'name', value: 'id', children: 'childs' };

const PagesMainInformationArticleTable: React.FC = ({ dispatch, openModel, getId }: any) => {
    const actionRef = useRef<ActionType>();
    const [list, setList] = useState<object[]>([])
    const [total, setTotal] = useState<number>(0)
    const [page, setPage] = useState<number>(1)
    const [pageSize, setPageSize] = useState<number>(10)

    const setId = (id: number) => {
        getId(id)
    }

    useEffect(() => {
        if (!openModel.openModal) {
            actionRef.current.reload();
        }
    }, [openModel.openModal])

    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                        colorLink: '#4FBE70',
                    }
                }}
            >
                <ProTable
                    size='small'
                    bordered={true}
                    scroll={{ x: 1300 }}
                    actionRef={actionRef}
                    dataSource={list}
                    columns={[ {
                        title: 'ID',
                        dataIndex: 'id',
                        width: 100,
                        search: false,
                    },
                        {
                            title: '文章名',
                            dataIndex: 'title',
                            width: 400,
                        },
                        {
                            title: '所属栏目',
                            dataIndex: 'section_name',
                            search: false
                        },
                       
                        {
                            title: '封面图',
                            dataIndex: 'cover_img',
                            search: false,
                            render: (_, record) => (<>
                                <Image src={`${Imageprefix}${record.cover_img}`} width={40} height={40}/>
                            </>
                            )
                        },
                        {
                            title: '置顶',
                            dataIndex: 'stick_top',
                            search: false,
                            render: (_, record) => (<>
                                {
                                    <>
                                        {record.stick_top === 1 ? <Tag color="green">置顶</Tag> : <Tag>未置顶</Tag>}
                                    </>
                                }

                            </>),
                        },
                        { 
                            title: '热门',
                            dataIndex: 'hot',
                            search: false,
                            render: (_, record) => (<>
                                {
                                    <>
                                        {record.hot === 1 ? <Tag >普通</Tag> : <Tag color="red">热门推荐</Tag>}
                                    </>
                                }

                            </>),
                        },
                        {
                            title: '作者',
                            dataIndex: 'author',
                            search: false
                        },
                        {
                            title: '操作',
                            width: 300,
                            key: 'option',
                            valueType: 'option',
                            fixed: 'right',
                            render: (_, record, action) => [
                                <Button key='1' type='link' onClick={() => {
                                    setId(record.id)
                                    dispatch({ type: 'openModel/getOpenModal', payload: true })
                                }}>编辑</Button>,
                                <Popconfirm
                                title="是否删除"
                                onConfirm={(e) => {
                                    PostTalentsinfoDel({ id: record.id }).then(res => {
                                        message.success('删除成功')
                                        actionRef.current?.reload();
                                    })
                                }}
                                okText="删除"
                                cancelText="取消"
                            >
                                <a
                                    key="delete"
                                >
                                    删除
                                </a>
                            </Popconfirm>
                            ],
                        },
                    ]}
                    rowKey="id"
                    pagination={{
                        current: page,
                        pageSize: pageSize,
                        showSizeChanger: true,
                        total: total,
                        pageSizeOptions: [9, 18, 27, 99],
                        onChange(page, pageSize) {
                            setPage(page)
                            setPageSize(pageSize)
                        },
                        onShowSizeChange(current, size) {
                            setPage(current)
                            setPageSize(size)
                        }
                    }}
                    request={async (params = {} as Record<string, any>) =>
                        GetTalentsinfoList({
                            page: page,
                            pagesize: pageSize,
                            sort: 'id',
                            sortby: 'desc',
                            keyword: params.name,
                            section_id: params.section_id
                        }).then(res => {
                            setList(res.data.articles)
                            setTotal(res.data.total)
                        })
                    }
                    headerTitle="公共人口信息"
                    toolBarRender={() => [
                        <Button type="primary" onClick={() => {
                            dispatch({ type: 'openModel/getOpenModal', payload: true })
                        }}>
                            公共人口信息
                        </Button>
                    ]}
                />
            </ConfigProvider>
        </>
    );
};


export default connect(({ openModel }: any) => ({
    openModel
}))(PagesMainInformationArticleTable);
